﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotNetNuke;
using DotNetNuke.Security;
using LinqThings4Sale;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Common;

namespace DotNetNuke.Modules.LinqThings4Sale
{
    public partial class View : DotNetNuke.Entities.Modules.PortalModuleBase, Entities.Modules.IActionable
    {
        #region ViewState
        [Serializable]
        public class Category
        {
            public string Name { get; set; }
        }

        public List<Category> Categories
        {
            get
            {
                if (ViewState["Categories"] == null)
                {
                    return new List<Category>();
                }
                else
                {
                    return (List<Category>)ViewState["Categories"];
                }
            }
            set
            {
                ViewState["Categories"] = value;
            }
        }
        #endregion

        protected void Page_Load(object sender, EventArgs e)
        {
            if (UserId != -1)
            {
                lnkAddListing.Text = "[Add My Listing]";
                lnkAddListing.Enabled = true;
            }
            else
            {
                lnkAddListing.Text = "You must be logged in to add a Listing";
                lnkAddListing.Enabled = false;
            }
        }

        #region LinqDataSource
        protected void LDSGrouping_Selecting(object sender, LinqDataSourceSelectEventArgs e)
        {
            e.WhereParameters["ModuleId"] = ModuleId;
        }
        #endregion

        #region LinkButton Events
        protected void lnkAddListing_Click(object sender, EventArgs e)
        {
            ModuleController objModules = new ModuleController();
            Response.Redirect(Globals.NavigateURL(PortalSettings.ActiveTab.TabID, "EditItem", "mid=" + ModuleId.ToString(), "RecordID=-1"));
        }

        protected void lnkSelect_Click(object sender, EventArgs e)
        {
            LinkButton objLinkButton = (LinkButton)sender;

            ModuleController objModules = new ModuleController();
            Response.Redirect(Globals.NavigateURL(PortalSettings.ActiveTab.TabID, "EditItem", "mid=" + ModuleId.ToString(), "RecordID=" + objLinkButton.CommandName));
        }
        #endregion

        #region ListView
        protected void lvItems_ItemDataBound(object sender, ListViewItemEventArgs e)
        {
            LinkButton LinkButton = (LinkButton)e.Item.FindControl("lnkSelect");

            if ((!PortalSecurity.IsInRole("Administrators"))
                & !(Entities.Users.UserController.GetCurrentUserInfo().UserID == Convert.ToInt16(LinkButton.CommandArgument)))
            {
                e.Item.Controls[1].Visible = false;
            }
        }

        protected void LVGroup_ItemDataBound(object sender, ListViewItemEventArgs e)
        {
            Panel Panel = (Panel)e.Item.FindControl("pnlItems");
            LinkButton objLinkButton = (LinkButton)e.Item.FindControl("MinMax");

            var results = from cat in Categories
                          where cat.Name == objLinkButton.CommandArgument
                          select cat;

            if (results.Count() != 0)
            {
                Panel.Visible = true;
                objLinkButton.Text = "-";
            }
        }
        #endregion

        #region IActionable Members

        public DotNetNuke.Entities.Modules.Actions.ModuleActionCollection ModuleActions
        {
            get
            {
                Entities.Modules.Actions.ModuleActionCollection Actions = new Entities.Modules.Actions.ModuleActionCollection();
                Actions.Add(GetNextActionID(),
                "Edit Categories",
                Entities.Modules.Actions.ModuleActionType.AddContent,
                "",
                "",
                EditUrl(),
                false,
                SecurityAccessLevel.Edit,
                true, false);
                return Actions;
            }
        }

        #endregion

        #region MinMax
        protected void MinMax_Click(object sender, EventArgs e)
        {
            LinkButton objLinkButton = (LinkButton)sender;

            var results = from cat in Categories
                          where cat.Name == objLinkButton.CommandArgument
                          select cat;

            if (objLinkButton.Text == "+")
            {
                // Only add this category if it does not already exist
                if (results.Count() == 0)
                {
                    // Add the Category
                    Category objCategory = new Category { Name = objLinkButton.CommandArgument };
                    List<Category> colCategories = Categories;
                    colCategories.Add(objCategory);
                    Categories = colCategories;
                }
            }
            else
            {
                // Only remove this category if it already exists
                if (results.Count() != 0)
                {
                    // Remove the Category
                    List<Category> colCategories = Categories;
                    Category objCategory = (Category)colCategories.FirstOrDefault(c => c.Name == objLinkButton.CommandArgument);
                    colCategories.Remove(objCategory);
                    Categories = colCategories;
                }
            }

            LVGroup.DataBind();
        }
        #endregion

    }
}